package com.cultural.heritage.service.common.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.IService;
import com.cultural.heritage.service.common.CommonService;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.function.Function;
import java.util.stream.Collectors;

@Service
public class CommonServiceImpl implements CommonService {


    /**
     * 取出一个集合的某个id列表, 去另外一个集合中筛选出属于这个id列表的集合
     */
    @Override
    public <T, R> List<R> getItemsByIds(List<T> records, IService<R> genericService, Function<T, Long> getId) {
        // 提取ID
        List<Long> ids = records.stream()
                .map(getId)  // 提取每个元素的ID
                .collect(Collectors.toList());

        // 构造查询条件
        QueryWrapper<R> queryWrapper = new QueryWrapper<>();
        queryWrapper.in("id", ids);

        // 返回查询结果
        return genericService.list(queryWrapper);
    }


    /**
     * 根据 ID 列表获取对应的实体列表
     */
    @Override
    public <T> List<T> getListByIds(List<Long> ids, IService<T> genericService) {
        // 构造查询条件
        QueryWrapper<T> queryWrapper = new QueryWrapper<>();
        queryWrapper.in("id", ids);  // 使用 IN 条件

        // 调用具体的服务执行查询
        return genericService.list(queryWrapper);
    }
}
